﻿using ICC4cPwmSdk.Device;
using ICC4cPwmSdk.Dtos;
using System.Collections.Generic;
using System;

namespace Icc4c_SimpleExample
{
    internal class VpmExample
    {
        // To run this example, rename VpmMain to Main and in Example.cs rename Main to ExMain for example
        // static void Main(string[] args) -> is always an entry point
        static void VPUMain(string[] args)
        {
            var controller = new ICC4cPwmSdkDeviceController();
            // Change comport number to correct value
            var connect = controller.Connect(12);
            if (!connect)
                throw new Exception("Failed to connect");

            // Check we connected correct device
            Console.WriteLine(controller.GetElectronicSerialNumber());

            var vectorToVpuMemory = new List<float>() { 0, 0.25f, 0.5f, 0.75f, 1, 2 };

            controller.InputStage.ArbitraryVector.SetUnitType(EChannel.Channel0, EICC4cPwmUnitType.FocalPower); 

            // Setting cycle values
            controller.InputStage.ArbitraryVector.SetCycles(EChannel.Channel0, 10); // Number of cycles 


            // Setting external trigger
            controller.InputStage.ArbitraryVector.SetExternalTrigger(EChannel.Channel0, EExternalTriggerType.RisingEdge); 

            // Setting external trigger GPIO
            controller.InputStage.ArbitraryVector.SetExternalTriggerGpio(EChannel.Channel0, EExternalTriggerGpiox.Input);

            // Set VPUs as input
            controller.SetActiveSystem(EIcc4cControlModeSystems.FocalPowerMode, EChannel.Channel0);
            controller.InputStage.ChangeActiveSystem(EChannel.Channel0, EInputSignalStageSystem.VectorPattern);

            // Set pattern vector memory
            controller.VectorPatternMemory.SetInputSignalVectorPatternValues(EChannel.Channel0, vectorToVpuMemory, 0, false);

            // Setting Frequency sample speed
            controller.InputStage.ArbitraryVector.SetSampleRate(EChannel.Channel0, 5);

            // Code for running the loop
            controller.InputStage.ArbitraryVector.SwitchArbitraryVector(EChannel.Channel0, false);

            while (true)
            {
                if (Console.ReadKey().Key == ConsoleKey.Q) // Wait for Q keyboard input to stop and break the loop;
                {
                    controller.InputStage.ArbitraryVector.SwitchArbitraryVector(EChannel.Channel0, false);
                    break; // Exit the loop
                }
            }

            controller.Disconnect(true);
        }
    }
}
